diff --git a/lib/Travelynx.pm b/lib/Travelynx.pm
index 6c2dd50962e0639c419a82ca0095881e89291498..8e6a465c85d67f5f20f851a1ff0d28aeda15b4cf 100755
--- a/lib/Travelynx.pm
+++ b/lib/Travelynx.pm
@@ -130,7 +130,7 @@ sub startup {
 	# security and usability for websites that want to maintain user's logged-in
 	# session after the user arrives from an external link". In practice,
 	# Safari (both iOS and macOS) does not send a SameSite=lax cookie when
-	# following a link from an external site. So, marudor.de providing a
+	# following a link from an external site. So, bahn.expert providing a
 	# checkin link to travelynx.de/s/whatever does not work because the user
 	# is not logged in due to Safari not sending the cookie.
 	#
diff --git a/lib/Travelynx/Command/database.pm b/lib/Travelynx/Command/database.pm
index 32522be5ace36cd2e9a7b090f6a9667478aa6d4a..d580c0535685b3924fc336d3415b2ab34a0cc941 100644
--- a/lib/Travelynx/Command/database.pm
+++ b/lib/Travelynx/Command/database.pm
@@ -1072,7 +1072,7 @@ my @migrations = (
 
 	# v24 -> v25
 	# travelynx 1.23 adds optional links to external services, e.g.
-	# DBF or marudor.de departure boards
+	# DBF or bahn.expert departure boards
 	sub {
 		my ($db) = @_;
 		$db->query(
diff --git a/lib/Travelynx/Model/Users.pm b/lib/Travelynx/Model/Users.pm
index 09d9538313989aa0e6391ac7ada94f0dd9d7d4b5..255b939cfc31e62beb74c6cec413ba417afa451a 100644
--- a/lib/Travelynx/Model/Users.pm
+++ b/lib/Travelynx/Model/Users.pm
@@ -13,9 +13,9 @@ use DateTime;
 my @sb_templates = (
 	undef,
 	[ 'DBF', 'https://dbf.finalrewind.org/{name}?rt=1#{tt}{tn}' ],
-	[ 'marudor.de', 'https://marudor.de/{name}#{id}' ],
+	[ 'marudor.de', 'https://bahn.expert/{name}#{id}' ],
 	[ 'NVM',        'https://nvm.finalrewind.org/board/{eva}#{tt}{tn}' ],
-	[ 'marudor.de/regional', 'https://marudor.de/regional/{name}#{id}' ],
+	[ 'marudor.de/regional', 'https://bahn.expert/regional/{name}#{id}' ],
 );
 
 sub new {
diff --git a/templates/_checked_in.html.ep b/templates/_checked_in.html.ep
index f2b6eba7ffee158ad8d2c427d249bdeb1bcca5db..040c5de28c08a88014ec7233a04fa76f9f7a1d20 100644
--- a/templates/_checked_in.html.ep
+++ b/templates/_checked_in.html.ep
@@ -78,7 +78,7 @@
 								% @wagons = reverse @wagons;
 							% }
 						% }
-						<a href="https://marudor.de/details/<%= $journey->{train_type} %>%20<%= $journey->{train_no} %>/<%= DateTime->now(time_zone => 'Europe/Berlin')->iso8601 %>?station=<%= $journey->{dep_eva} %>">
+						<a href="https://bahn.expert/details/<%= $journey->{train_type} %>%20<%= $journey->{train_no} %>/<%= DateTime->now(time_zone => 'Europe/Berlin')->iso8601 %>?station=<%= $journey->{dep_eva} %>">
 						%= $direction
 						% for my $wagon (@wagons) {
 							% if (not ($wagon->is_locomotive or $wagon->is_powercar)) {
@@ -297,7 +297,7 @@
 				% }
 			</div>
 			<div class="card-action">
-				% my $url = 'https://marudor.de/details/' . $journey->{train_type} . ' ' . $journey->{train_no} . '/' . DateTime->now(time_zone => 'Europe/Berlin')->epoch . '000';
+				% my $url = 'https://bahn.expert/details/' . $journey->{train_type} . ' ' . $journey->{train_no} . '/' . DateTime->now(time_zone => 'Europe/Berlin')->epoch . '000';
 				<a style="margin-right: 0;" href="<%= $url %>" aria-label="Zuglauf"><i class="material-icons left">timeline</i> Zuglauf</a>
 				% if ($journey->{extra_data}{trip_id}) {
 					<a class="right" style="margin-right: 0;" href="https://dbf.finalrewind.org/map/<%= $journey->{extra_data}{trip_id} %>/<%= $journey->{train_line} || 0 %>?from=<%= $journey->{dep_name} %>&amp;to=<%= $journey->{arr_name} %>&amp;dark=<%= (session('theme') and session('theme') eq 'dark') ? 1 : 0 %>"><i class="material-icons left" aria-hidden="true">map</i> Karte</a>
diff --git a/templates/_public_status_card.html.ep b/templates/_public_status_card.html.ep
index 0f9019b9e977a5fe3adedad1a288d6faff739bb0..494532b4bf4e68a6f8ee3595dabc6de00ef90543 100644
--- a/templates/_public_status_card.html.ep
+++ b/templates/_public_status_card.html.ep
@@ -151,7 +151,7 @@
 			% if ($journey->{traewelling_url}) {
 				<a style="margin-right: 0;" href="<%= $journey->{traewelling_url} %>"><i class="material-icons left">timeline</i> Träwelling</a>
 			% } else {
-				% my $url = 'https://marudor.de/details/' . $journey->{train_type} . ' ' . $journey->{train_no} . '/' . DateTime->now(time_zone => 'Europe/Berlin')->epoch . '000';
+				% my $url = 'https://bahn.expert/details/' . $journey->{train_type} . ' ' . $journey->{train_no} . '/' . DateTime->now(time_zone => 'Europe/Berlin')->epoch . '000';
 				<a style="margin-right: 0;" href="<%= $url %>"><i class="material-icons left">timeline</i> Zuglauf</a>
 			% }
 			% if ($journey->{extra_data}{trip_id}) {
diff --git a/templates/use_external_links.html.ep b/templates/use_external_links.html.ep
index d58e33dccb628b0dafcab3ab5bdd3ab0f66eebbf..4540e40f91b3d28939ac1808420549c5c4f9195c 100644
--- a/templates/use_external_links.html.ep
+++ b/templates/use_external_links.html.ep
@@ -42,7 +42,7 @@
 			<div>
 				<label>
 					%= radio_button stationboard => '2'
-					<span><a href="https://marudor.de/">marudor.de</a> (Schienenverkehr)</span>
+					<span><a href="https://bahn.expert/">bahn.expert</a> (Schienenverkehr)</span>
 				</label>
 			</div>
 		</div>
@@ -52,7 +52,7 @@
 			<div>
 				<label>
 					%= radio_button stationboard => '4'
-					<span><a href="https://marudor.de/regional">marudor.de/regional</a> (Nahverkehr)</span>
+					<span><a href="https://bahn.expert/regional">bahn.expert/regional</a> (Nahverkehr)</span>
 				</label>
 			</div>
 		</div>
diff --git a/contrib/i3bar-snippet.py b/contrib/i3bar-snippet.py
index f2ce6a5da0058b943bfe7ffd05d17be225374b60..c02d63c0b060375b4d242cdb75aa3de665de1468 100755
--- a/contrib/i3bar-snippet.py
+++ b/contrib/i3bar-snippet.py
@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 # This script queries the Travelynx API if you are checked into a train. If
 # yes, marudor.de is additionally queried for the next stop, and a JSON object
 # like this is written to stdout:
 # {"full_text": "RE26824, next: D\u00fcren at <span fgcolor=\"#ff0000\">15:38+5</span>, dest: Aachen Hbf at <span fgcolor=\"#ff0000\">16:07+5</span>", "markup": "pango"},
 # The script then exits.
@@ -80,7 +80,7 @@ predicted_arrival_timestamp = j["toStation"]["realTime"]
 delay = (predicted_arrival_timestamp - scheduled_arrival_timestamp) / 60
 
 try:
-    details_res = requests.get(f"https://marudor.de/api/hafas/v2/details/{train}")
+    details_res = requests.get(f"https://bahn.expert/api/hafas/v2/details/{train}")
     details = details_res.json()
     # print(json.dumps(details, sort_keys=True, indent=4), file=sys.stderr)
     next_stop_name = details["currentStop"]["station"]["title"]
@@ -1,7 +1,7 @@
 
 # This script queries the Travelynx API if you are checked into a train. If
-# yes, marudor.de is additionally queried for the next stop, and a JSON object
+# yes, bahn.expert is additionally queried for the next stop, and a JSON object
 # like this is written to stdout:
 # {"full_text": "RE26824, next: D\u00fcren at <span fgcolor=\"#ff0000\">15:38+5</span>, dest: Aachen Hbf at <span fgcolor=\"#ff0000\">16:07+5</span>", "markup": "pango"},